#include <avr/io.h>

/*
 * Functie de initializare a controllerului USART
 */
void USART0_init()
{
    /* seteaza baud rate la 9600 */
    UBRR0H = 0;
    UBRR0L = 103;

    /* porneste transmitatorul */
    UCSR0B = (1<<RXEN0);

    /* seteaza formatul frame-ului: 8 biti de date, 1 biti de stop, paritate para */
    UCSR0C &= ~(1<<USBS0);
    UCSR0C |= (2<<UCSZ00);
    UCSR0C |= (1<<UPM01);
}

/*
 * Functie ce primeste un caracter prin USART
 *
 * @return - caracterul primit
 */
char USART0_receive()
{
    /* asteapta cat timp bufferul e gol */
    while(!(UCSR0A & (1<<RXC0)));

    /* returneaza datele din buffer */
    return UDR0;
}

/* Functie de initializare a motoarelor */
void motors_init()
{
	/* seteaza pinii ca fiind de output */
	DDRC |= (1 << PC0);
	DDRC |= (1 << PC1);
	DDRC |= (1 << PC2);
	DDRC |= (1 << PC3);

	/* initial masina se afla in repaus */
	PORTC &= ~(1 << PC0);
	PORTC &= ~(1 << PC1);
	PORTC &= ~(1 << PC2);
	PORTC &= ~(1 << PC3);
}

int main()
{
	char char_received;

	USART0_init();
	motors_init();

	while (1) {
		char_received = USART0_receive();

		if (char_received == 'F') {		/* deplasare fata */ 
			PORTC |= (1 << PC0);
			PORTC &= ~(1 << PC1);
			PORTC |= (1 << PC2);
			PORTC &= ~(1 << PC3);
		} else if (char_received == 'B') {	/* deplasare spate */
			PORTC &= ~(1 << PC0);
			PORTC |= (1 << PC1);
			PORTC &= ~(1 << PC2);
			PORTC |= (1 << PC3);
		} else if (char_received == 'L') {	/* deplasare stanga */
			PORTC &= ~(1 << PC0);
			PORTC &= ~(1 << PC1);
			PORTC |= (1 << PC2);
			PORTC &= ~(1 << PC3);
		} else if (char_received == 'R') {	/* deplasare dreapta */
			PORTC |= (1 << PC0);
			PORTC &= ~(1 << PC1);
			PORTC &= ~(1 << PC2);
			PORTC &= ~(1 << PC3);
		} else if (char_received == 'S') {	/* stop */
			PORTC &= ~(1 << PC0);
			PORTC &= ~(1 << PC1);
			PORTC &= ~(1 << PC2);
			PORTC &= ~(1 << PC3);
		}
	}

	return 0;
}
